@@ -9,7 +9,7 @@ from typing_extensions import Final
 from textual import constants, events, messages
 from textual._ansi_sequences import ANSI_SEQUENCES_KEYS, IGNORE_SEQUENCE
 from textual._keyboard_protocol import FUNCTIONAL_KEYS
-from textual._parser import Parser, ParseTimeout, Peek1, Read1, TokenCallback
+from textual._parser import ParseEOF, Parser, ParseTimeout, Peek1, Read1, TokenCallback
 from textual.keys import KEY_NAME_REPLACEMENTS, Keys, _character_to_key
 from textual.message import Message
 
@@ -43,15 +43,21 @@ _re_in_band_window_resize: Final = re.compile(
 )
 
 
-IS_ITERM = os.environ.get("TERM_PROGRAM", "") == "iTerm.app"
+IS_ITERM = (
+    os.environ.get("LC_TERMINAL", "") == "iTerm2"
+    or os.environ.get("TERM_PROGRAM", "") == "iTerm.app"
+)
 
 
 class XTermParser(Parser[Message]):
     _re_sgr_mouse = re.compile(r"\x1b\[<(\d+);(\d+);(\d+)([Mm])")
 
     def __init__(self, debug: bool = False) -> None:
-        self.last_x = 0
-        self.last_y = 0
+        self.last_x = 0.0
+        self.last_y = 0.0
+        self.mouse_pixels = False
+        self.terminal_size: tuple[int, int] | None = None
+        self.terminal_pixel_size: tuple[int, int] | None = None
         self._debug_log_file = open("keys.log", "at") if debug else None
         super().__init__()
         self.debug_log("---")
@@ -70,10 +76,22 @@ class XTermParser(Parser[Message]):
         if sgr_match:
             _buttons, _x, _y, state = sgr_match.groups()
             buttons = int(_buttons)
-            x = int(_x) - 1
-            y = int(_y) - 1
-            delta_x = x - self.last_x
-            delta_y = y - self.last_y
+            x = float(int(_x) - 1)
+            y = float(int(_y) - 1)
+            if (
+                self.mouse_pixels
+                and self.terminal_pixel_size is not None
+                and self.terminal_size is not None
+            ):
+                pixel_width, pixel_height = self.terminal_pixel_size
+                width, height = self.terminal_size
+                x_ratio = pixel_width / width
+                y_ratio = pixel_height / height
+                x /= x_ratio
+                y /= y_ratio
+
+            delta_x = int(x) - int(self.last_x)
+            delta_y = int(y) - int(self.last_y)
             self.last_x = x
             self.last_y = y
             event_class: type[events.MouseEvent]
@@ -120,6 +138,9 @@ class XTermParser(Parser[Message]):
         def on_token(token: Message) -> None:
             """Hook to log events."""
             self.debug_log(str(token))
+            if isinstance(token, events.Resize):
+                self.terminal_size = token.size
+                self.terminal_pixel_size = token.pixel_size
             token_callback(token)
 
         def on_key_token(event: events.Key) -> None:
@@ -166,7 +187,7 @@ class XTermParser(Parser[Message]):
 
             try:
                 character = yield read1()
-            except EOFError:
+            except ParseEOF:
                 return
 
             if bracketed_paste:
@@ -195,7 +216,7 @@ class XTermParser(Parser[Message]):
                 except ParseTimeout:
                     send_escape()
                     break
-                except EOFError:
+                except ParseEOF:
                     send_escape()
                     return
 
@@ -228,6 +249,10 @@ class XTermParser(Parser[Message]):
                         (int(width), int(height)),
                         (int(pixel_width), int(pixel_height)),
                     )
+
+                    self.terminal_size = resize_event.size
+                    self.terminal_pixel_size = resize_event.pixel_size
+                    self.mouse_pixels = True
                     on_token(resize_event)
                     break
 
@@ -267,10 +292,16 @@ class XTermParser(Parser[Message]):
                         setting_parameter = int(mode_report_match["setting_parameter"])
                         if mode_id == "2026" and setting_parameter > 0:
                             on_token(messages.TerminalSupportsSynchronizedOutput())
-                        elif mode_id == "2048" and not IS_ITERM:
-                            # TODO: remove "and not IS_ITERM" when https://gitlab.com/gnachman/iterm2/-/issues/11961 is fixed
-                            in_band_event = messages.TerminalSupportInBandWindowResize.from_setting_parameter(
-                                setting_parameter
+                        elif (
+                            mode_id == "2048"
+                            and constants.SMOOTH_SCROLL
+                            and not IS_ITERM
+                        ):
+                            # TODO: iTerm is buggy in one or more of the protocols required here
+                            in_band_event = (
+                                messages.InBandWindowResize.from_setting_parameter(
+                                    setting_parameter
+                                )
                             )
                             on_token(in_band_event)
                         break
