@@ -47,6 +47,7 @@ from textual.css.tokenize import IDENTIFIER
 from textual.css.tokenizer import TokenError
 from textual.message_pump import MessagePump
 from textual.reactive import Reactive, ReactiveError, _Mutated, _watch
+from textual.style import Style as VisualStyle
 from textual.timer import Timer
 from textual.walk import walk_breadth_first, walk_depth_first
 from textual.worker_manager import WorkerManager
@@ -223,7 +224,7 @@ class DOMNode(MessagePump):
         self._has_hover_style: bool = False
         self._has_focus_within: bool = False
         self._has_order_style: bool = False
-        """The node has an ordered dependent pseudo-style (`:odd`, `:even`, `:first-of-type`, `:last-of-type`)"""
+        """The node has an ordered dependent pseudo-style (`:odd`, `:even`, `:first-of-type`, `:last-of-type`, `:first-child`, `:last-child`)"""
         self._has_odd_or_even: bool = False
         """The node has the pseudo class `odd` or `even`."""
         self._reactive_connect: (
@@ -234,6 +235,17 @@ class DOMNode(MessagePump):
 
         super().__init__()
 
+    def _get_dom_base(self) -> DOMNode:
+        """Get the DOM base node (typically self).
+
+        All DOM queries on this node will use the return value as the root node.
+        This method allows the App to query the default screen, and not the active screen.
+
+        Returns:
+            DOMNode.
+        """
+        return self
+
     def set_reactive(
         self, reactive: Reactive[ReactiveType], value: ReactiveType
     ) -> None:
@@ -1023,6 +1035,12 @@ class DOMNode(MessagePump):
             node.styles.text_style for node in reversed(self.ancestors_with_self)
         )
 
+    @property
+    def selection_style(self) -> Style:
+        """The style of selected text."""
+        style = self.screen.get_component_rich_style("screen--selection")
+        return style
+
     @property
     def rich_style(self) -> Style:
         """Get a Rich Style object for this DOMNode.
@@ -1081,8 +1099,8 @@ class DOMNode(MessagePump):
 
     def _get_title_style_information(
         self, background: Color
-    ) -> tuple[Color, Color, Style]:
-        """Get a Rich Style object for for titles.
+    ) -> tuple[Color, Color, VisualStyle]:
+        """Get a Visual Style object for for titles.
 
         Args:
             background: The background color.
@@ -1090,6 +1108,7 @@ class DOMNode(MessagePump):
         Returns:
             A Rich style.
         """
+
         styles = self.styles
         if styles.auto_border_title_color:
             color = background.get_contrast_text(styles.border_title_color.a)
@@ -1098,12 +1117,12 @@ class DOMNode(MessagePump):
         return (
             color,
             styles.border_title_background,
-            styles.border_title_style,
+            VisualStyle.from_rich_style(styles.border_title_style),
         )
 
     def _get_subtitle_style_information(
         self, background: Color
-    ) -> tuple[Color, Color, Style]:
+    ) -> tuple[Color, Color, VisualStyle]:
         """Get a Rich Style object for for titles.
 
         Args:
@@ -1120,7 +1139,7 @@ class DOMNode(MessagePump):
         return (
             color,
             styles.border_subtitle_background,
-            styles.border_subtitle_style,
+            VisualStyle.from_rich_style(styles.border_subtitle_style),
         )
 
     @property
@@ -1372,10 +1391,11 @@ class DOMNode(MessagePump):
         from textual.css.query import DOMQuery, QueryType
         from textual.widget import Widget
 
+        node = self._get_dom_base()
         if isinstance(selector, str) or selector is None:
-            return DOMQuery[Widget](self, filter=selector)
+            return DOMQuery[Widget](node, filter=selector)
         else:
-            return DOMQuery[QueryType](self, filter=selector.__name__)
+            return DOMQuery[QueryType](node, filter=selector.__name__)
 
     if TYPE_CHECKING:
 
@@ -1403,10 +1423,11 @@ class DOMNode(MessagePump):
         from textual.css.query import DOMQuery, QueryType
         from textual.widget import Widget
 
+        node = self._get_dom_base()
         if isinstance(selector, str) or selector is None:
-            return DOMQuery[Widget](self, deep=False, filter=selector)
+            return DOMQuery[Widget](node, deep=False, filter=selector)
         else:
-            return DOMQuery[QueryType](self, deep=False, filter=selector.__name__)
+            return DOMQuery[QueryType](node, deep=False, filter=selector.__name__)
 
     if TYPE_CHECKING:
 
@@ -1441,6 +1462,8 @@ class DOMNode(MessagePump):
         """
         _rich_traceback_omit = True
 
+        base_node = self._get_dom_base()
+
         if isinstance(selector, str):
             query_selector = selector
         else:
@@ -1454,20 +1477,20 @@ class DOMNode(MessagePump):
             ) from None
 
         if all(selectors.is_simple for selectors in selector_set):
-            cache_key = (self._nodes._updates, query_selector, expect_type)
-            cached_result = self._query_one_cache.get(cache_key)
+            cache_key = (base_node._nodes._updates, query_selector, expect_type)
+            cached_result = base_node._query_one_cache.get(cache_key)
             if cached_result is not None:
                 return cached_result
         else:
             cache_key = None
 
-        for node in walk_depth_first(self, with_root=False):
+        for node in walk_depth_first(base_node, with_root=False):
             if not match(selector_set, node):
                 continue
             if expect_type is not None and not isinstance(node, expect_type):
                 continue
             if cache_key is not None:
-                self._query_one_cache[cache_key] = node
+                base_node._query_one_cache[cache_key] = node
             return node
 
         raise NoMatches(f"No nodes match {selector!r} on {self!r}")
@@ -1510,6 +1533,8 @@ class DOMNode(MessagePump):
         """
         _rich_traceback_omit = True
 
+        base_node = self._get_dom_base()
+
         if isinstance(selector, str):
             query_selector = selector
         else:
@@ -1523,14 +1548,14 @@ class DOMNode(MessagePump):
             ) from None
 
         if all(selectors.is_simple for selectors in selector_set):
-            cache_key = (self._nodes._updates, query_selector, expect_type)
-            cached_result = self._query_one_cache.get(cache_key)
+            cache_key = (base_node._nodes._updates, query_selector, expect_type)
+            cached_result = base_node._query_one_cache.get(cache_key)
             if cached_result is not None:
                 return cached_result
         else:
             cache_key = None
 
-        children = walk_depth_first(self, with_root=False)
+        children = walk_depth_first(base_node, with_root=False)
         iter_children = iter(children)
         for node in iter_children:
             if not match(selector_set, node):
@@ -1545,11 +1570,63 @@ class DOMNode(MessagePump):
                         "Call to query_one resulted in more than one matched node"
                     )
             if cache_key is not None:
-                self._query_one_cache[cache_key] = node
+                base_node._query_one_cache[cache_key] = node
             return node
 
         raise NoMatches(f"No nodes match {selector!r} on {self!r}")
 
+    if TYPE_CHECKING:
+
+        @overload
+        def query_ancestor(self, selector: str) -> DOMNode: ...
+
+        @overload
+        def query_ancestor(self, selector: type[QueryType]) -> QueryType: ...
+
+        @overload
+        def query_ancestor(
+            self, selector: str, expect_type: type[QueryType]
+        ) -> QueryType: ...
+
+    def query_ancestor(
+        self,
+        selector: str | type[QueryType],
+        expect_type: type[QueryType] | None = None,
+    ) -> DOMNode | None:
+        """Get an ancestor which matches a query.
+
+        Args:
+            selector: A TCSS selector.
+            expect_type: Expected type, or `None` for any DOMNode.
+
+        Raises:
+            InvalidQueryFormat: If the selector is invalid.
+            NoMatches: If there are no matching ancestors.
+
+        Returns:
+            A DOMNode or subclass if `expect_type` is provided.
+        """
+        base_node = self._get_dom_base()
+        if isinstance(selector, str):
+            query_selector = selector
+        else:
+            query_selector = selector.__name__
+
+        try:
+            selector_set = parse_selectors(query_selector)
+        except TokenError:
+            raise InvalidQueryFormat(
+                f"Unable to parse {query_selector!r} as a query; check for syntax errors"
+            ) from None
+        if base_node.parent is not None:
+            for node in base_node.parent.ancestors_with_self:
+                if not match(selector_set, node):
+                    continue
+                if expect_type is not None and not isinstance(node, expect_type):
+                    continue
+                return node
+        raise NoMatches(f"No ancestor matches {selector!r} on {self!r}")
+
     def set_styles(self, css: str | None = None, **update_styles: Any) -> Self:
         """Set custom styles on this object.
 
@@ -1741,7 +1818,8 @@ class DOMNode(MessagePump):
         See [actions](/guide/actions#dynamic-actions) for how to use this method.
 
         """
-        self.screen.refresh_bindings()
+        if self._is_mounted:
+            self.screen.refresh_bindings()
 
     async def action_toggle(self, attribute_name: str) -> None:
         """Toggle an attribute on the node.
