@@ -22,10 +22,9 @@ from typing import (
 
 import rich.repr
 
-from . import events
-from ._callback import count_parameters
-from ._context import active_message_pump
-from ._types import (
+from textual import events
+from textual._callback import count_parameters
+from textual._types import (
     MessageTarget,
     WatchCallbackBothValuesType,
     WatchCallbackNewValueType,
@@ -34,7 +33,7 @@ from ._types import (
 )
 
 if TYPE_CHECKING:
-    from .dom import DOMNode
+    from textual.dom import DOMNode
 
     Reactable = DOMNode
 
@@ -42,6 +41,13 @@ ReactiveType = TypeVar("ReactiveType")
 ReactableType = TypeVar("ReactableType", bound="DOMNode")
 
 
+class _Mutated:
+    """A wrapper to indicate a value was mutated."""
+
+    def __init__(self, value: Any) -> None:
+        self.value = value
+
+
 class ReactiveError(Exception):
     """Base class for reactive errors."""
 
@@ -75,8 +81,8 @@ def invoke_watcher(
     _rich_traceback_omit = True
 
     param_count = count_parameters(watch_function)
-    reset_token = active_message_pump.set(watcher_object)
-    try:
+
+    with watcher_object._context():
         if param_count == 2:
             watch_result = cast(WatchCallbackBothValuesType, watch_function)(
                 old_value, value
@@ -90,8 +96,6 @@ def invoke_watcher(
             watcher_object.call_next(
                 partial(await_watcher, watcher_object, watch_result)
             )
-    finally:
-        active_message_pump.reset(reset_token)
 
 
 @rich.repr.auto
@@ -107,6 +111,7 @@ class Reactive(Generic[ReactiveType]):
         compute: Run compute methods when attribute is changed.
         recompose: Compose the widget again when the attribute changes.
         bindings: Refresh bindings when the reactive changes.
+        toggle_class: An optional TCSS classname(s) to toggle based on the truthiness of the value.
     """
 
     _reactives: ClassVar[dict[str, object]] = {}
@@ -122,6 +127,7 @@ class Reactive(Generic[ReactiveType]):
         compute: bool = True,
         recompose: bool = False,
         bindings: bool = False,
+        toggle_class: str | None = None,
     ) -> None:
         self._default = default
         self._layout = layout
@@ -131,6 +137,7 @@ class Reactive(Generic[ReactiveType]):
         self._run_compute = compute
         self._recompose = recompose
         self._bindings = bindings
+        self._toggle_class = toggle_class
         self._owner: Type[MessageTarget] | None = None
         self.name: str
 
@@ -145,6 +152,18 @@ class Reactive(Generic[ReactiveType]):
         yield "bindings", self._bindings, False
         yield "name", getattr(self, "name", None), None
 
+    @classmethod
+    def _clear_watchers(cls, obj: Reactable) -> None:
+        """Clear any watchers on a given object.
+
+        Args:
+            obj: A reactive object.
+        """
+        try:
+            getattr(obj, "__watchers").clear()
+        except AttributeError:
+            pass
+
     @property
     def owner(self) -> Type[MessageTarget]:
         """The owner (class) where the reactive was declared."""
@@ -159,6 +178,7 @@ class Reactive(Generic[ReactiveType]):
             name: Name of attribute.
         """
         _rich_traceback_omit = True
+
         internal_name = f"_reactive_{name}"
         if hasattr(obj, internal_name):
             # Attribute already has a value
@@ -251,8 +271,7 @@ class Reactive(Generic[ReactiveType]):
             raise ReactiveError(
                 f"Node is missing data; Check you are calling super().__init__(...) in the {obj.__class__.__name__}() constructor, before getting reactives."
             )
-        internal_name = self.internal_name
-        if not hasattr(obj, internal_name):
+        if not hasattr(obj, internal_name := self.internal_name):
             self._initialize_reactive(obj, self.name)
 
         if hasattr(obj, self.compute_name):
@@ -273,6 +292,10 @@ class Reactive(Generic[ReactiveType]):
                 f"Node is missing data; Check you are calling super().__init__(...) in the {obj.__class__.__name__}() constructor, before setting reactives."
             )
 
+        if isinstance(value, _Mutated):
+            value = value.value
+            always = True
+
         self._initialize_reactive(obj, self.name)
 
         if hasattr(obj, self.compute_name):
@@ -289,6 +312,11 @@ class Reactive(Generic[ReactiveType]):
         public_validate_function = getattr(obj, f"validate_{name}", None)
         if callable(public_validate_function):
             value = public_validate_function(value)
+
+        # Toggle the classes using the value's truthiness
+        if (toggle_class := self._toggle_class) is not None:
+            obj.set_class(bool(value), *toggle_class.split())
+
         # If the value has changed, or this is the first time setting the value
         if always or self._always_update or current_value != value:
             # Store the internal value
@@ -386,7 +414,9 @@ class reactive(Reactive[ReactiveType]):
         repaint: Perform a repaint on change.
         init: Call watchers on initialize (post mount).
         always_update: Call watchers even when the new value equals the old value.
+        recompose: Compose the widget again when the attribute changes.
         bindings: Refresh bindings when the reactive changes.
+        toggle_class: An optional TCSS classname(s) to toggle based on the truthiness of the value.
     """
 
     def __init__(
@@ -399,6 +429,7 @@ class reactive(Reactive[ReactiveType]):
         always_update: bool = False,
         recompose: bool = False,
         bindings: bool = False,
+        toggle_class: str | None = None,
     ) -> None:
         super().__init__(
             default,
@@ -408,6 +439,7 @@ class reactive(Reactive[ReactiveType]):
             always_update=always_update,
             recompose=recompose,
             bindings=bindings,
+            toggle_class=toggle_class,
         )
 
 
@@ -419,6 +451,7 @@ class var(Reactive[ReactiveType]):
         init: Call watchers on initialize (post mount).
         always_update: Call watchers even when the new value equals the old value.
         bindings: Refresh bindings when the reactive changes.
+        toggle_class: An optional TCSS classname(s) to toggle based on the truthiness of the value.
     """
 
     def __init__(
@@ -427,6 +460,7 @@ class var(Reactive[ReactiveType]):
         init: bool = True,
         always_update: bool = False,
         bindings: bool = False,
+        toggle_class: str | None = None,
     ) -> None:
         super().__init__(
             default,
@@ -435,6 +469,7 @@ class var(Reactive[ReactiveType]):
             init=init,
             always_update=always_update,
             bindings=bindings,
+            toggle_class=toggle_class,
         )
 
 
@@ -457,9 +492,8 @@ def _watch(
     """
     if not hasattr(obj, "__watchers"):
         setattr(obj, "__watchers", {})
-    watchers: dict[str, list[tuple[Reactable, WatchCallbackType]]] = getattr(
-        obj, "__watchers"
-    )
+    watchers: dict[str, list[tuple[Reactable, WatchCallbackType]]]
+    watchers = getattr(obj, "__watchers")
     watcher_list = watchers.setdefault(attribute_name, [])
     if any(callback == callback_from_list for _, callback_from_list in watcher_list):
         return
