@@ -6,7 +6,6 @@ from typing import TYPE_CHECKING, cast
 import rich.repr
 from rich.cells import cell_len
 from rich.console import ConsoleRenderable, RenderableType
-from rich.text import Text, TextType
 from typing_extensions import Literal, Self
 
 from textual import events
@@ -14,11 +13,13 @@ from textual import events
 if TYPE_CHECKING:
     from textual.app import RenderResult
 
+from rich.style import Style
+
 from textual.binding import Binding
+from textual.content import Content, ContentText
 from textual.css._error_tools import friendly_list
 from textual.geometry import Size
 from textual.message import Message
-from textual.pad import HorizontalPad
 from textual.reactive import reactive
 from textual.widget import Widget
 
@@ -36,47 +37,59 @@ class InvalidButtonVariant(Exception):
 
 
 class Button(Widget, can_focus=True):
-    """A simple clickable button."""
+    """A simple clickable button.
+
+    Clicking the button will send a [Button.Pressed][textual.widgets.Button.Pressed] message,
+    unless the `action` parameter is provided.
+
+    """
 
     DEFAULT_CSS = """
     Button {
         width: auto;
         min-width: 16;
         height: auto;
-        background: $panel;
-        color: $text;
+        color: $button-foreground;
+        background: $surface;
         border: none;
-        border-top: tall $panel-lighten-2;
-        border-bottom: tall $panel-darken-3;
+        border-top: tall $surface-lighten-1;
+        border-bottom: tall $surface-darken-1;
         text-align: center;
         content-align: center middle;
         text-style: bold;
+        line-pad: 1;
 
+        &.-textual-compact {
+            border: none !important;
+        }
 
+        &:disabled {            
+            text-opacity: 0.6;
+        }
+        
         &:focus {
-            text-style: bold reverse;
+            text-style: $button-focus-text-style;
+            background-tint: $foreground 5%;
         }
         &:hover {
-            border-top: tall $panel;
-            background: $panel-darken-2;
-            color: $text;
+            border-top: tall $surface;
+            background: $surface-darken-1;
         }
         &.-active {
-            background: $panel;
-            border-bottom: tall $panel-lighten-2;
-            border-top: tall $panel-darken-2;
+            background: $surface;
+            border-bottom: tall $surface-lighten-1;
+            border-top: tall $surface-darken-1;
             tint: $background 30%;
         }
 
         &.-primary {
+            color: $button-color-foreground;
             background: $primary;
-            color: $text;
             border-top: tall $primary-lighten-3;
             border-bottom: tall $primary-darken-3;
 
             &:hover {
                 background: $primary-darken-2;
-                color: $text;
                 border-top: tall $primary;
             }
 
@@ -88,14 +101,13 @@ class Button(Widget, can_focus=True):
         }
 
         &.-success {
+            color: $button-color-foreground;
             background: $success;
-            color: $text;
             border-top: tall $success-lighten-2;
             border-bottom: tall $success-darken-3;
 
             &:hover {
                 background: $success-darken-2;
-                color: $text;
                 border-top: tall $success;
             }
 
@@ -107,14 +119,13 @@ class Button(Widget, can_focus=True):
         }
 
         &.-warning{
+            color: $button-color-foreground;
             background: $warning;
-            color: $text;
             border-top: tall $warning-lighten-2;
             border-bottom: tall $warning-darken-3;
 
             &:hover {
                 background: $warning-darken-2;
-                color: $text;
                 border-top: tall $warning;
             }
 
@@ -126,14 +137,13 @@ class Button(Widget, can_focus=True):
         }
 
         &.-error {
+            color: $button-color-foreground;
             background: $error;
-            color: $text;
             border-top: tall $error-lighten-2;
             border-bottom: tall $error-darken-3;
 
             &:hover {
                 background: $error-darken-1;
-                color: $text;
                 border-top: tall $error;
             }
 
@@ -148,14 +158,17 @@ class Button(Widget, can_focus=True):
 
     BINDINGS = [Binding("enter", "press", "Press button", show=False)]
 
-    label: reactive[TextType] = reactive[TextType]("")
+    label: reactive[ContentText] = reactive[ContentText](Content.empty)
     """The text label that appears within the button."""
 
     variant = reactive("default", init=False)
     """The variant name for the button."""
 
+    compact = reactive(False, toggle_class="-textual-compact")
+    """Make the button compact (without borders)."""
+
     class Pressed(Message):
-        """Event sent when a `Button` is pressed.
+        """Event sent when a `Button` is pressed and there is no Button action.
 
         Can be handled using `on_button_pressed` in a subclass of
         [`Button`][textual.widgets.Button] or in a parent widget in the DOM.
@@ -176,7 +189,7 @@ class Button(Widget, can_focus=True):
 
     def __init__(
         self,
-        label: TextType | None = None,
+        label: ContentText | None = None,
         variant: ButtonVariant = "default",
         *,
         name: str | None = None,
@@ -184,6 +197,8 @@ class Button(Widget, can_focus=True):
         classes: str | None = None,
         disabled: bool = False,
         tooltip: RenderableType | None = None,
+        action: str | None = None,
+        compact: bool = False,
     ):
         """Create a Button widget.
 
@@ -195,20 +210,26 @@ class Button(Widget, can_focus=True):
             classes: The CSS classes of the button.
             disabled: Whether the button is disabled or not.
             tooltip: Optional tooltip.
+            action: Optional action to run when clicked.
+            compact: Enable compact button style.
         """
         super().__init__(name=name, id=id, classes=classes, disabled=disabled)
 
         if label is None:
             label = self.css_identifier_styled
 
-        self.label = label
+        self.label = Content.from_text(label)
         self.variant = variant
+        self.action = action
+        self.compact = compact
         self.active_effect_duration = 0.2
         """Amount of time in seconds the button 'press' animation lasts."""
+
         if tooltip is not None:
             self.tooltip = tooltip
 
     def get_content_width(self, container: Size, viewport: Size) -> int:
+        assert isinstance(self.label, Content)
         try:
             return max([cell_len(line) for line in self.label.plain.splitlines()]) + 2
         except ValueError:
@@ -230,25 +251,17 @@ class Button(Widget, can_focus=True):
         self.remove_class(f"-{old_variant}")
         self.add_class(f"-{variant}")
 
-    def validate_label(self, label: TextType) -> Text:
+    def validate_label(self, label: ContentText) -> Content:
         """Parse markup for self.label"""
-        if isinstance(label, str):
-            return Text.from_markup(label)
-        return label
+        return Content.from_text(label)
 
     def render(self) -> RenderResult:
-        assert isinstance(self.label, Text)
-        label = self.label.copy()
-        label.stylize_before(self.rich_style)
-        return HorizontalPad(
-            label,
-            1,
-            1,
-            self.rich_style,
-            self._get_rich_justify() or "center",
-        )
+        assert isinstance(self.label, Content)
+        return self.label
 
-    def post_render(self, renderable: RenderableType) -> ConsoleRenderable:
+    def post_render(
+        self, renderable: RenderableType, base_style: Style
+    ) -> ConsoleRenderable:
         return cast(ConsoleRenderable, renderable)
 
     async def _on_click(self, event: events.Click) -> None:
@@ -269,7 +282,12 @@ class Button(Widget, can_focus=True):
         # Manage the "active" effect:
         self._start_active_affect()
         # ...and let other components know that we've just been clicked:
-        self.post_message(Button.Pressed(self))
+        if self.action is None:
+            self.post_message(Button.Pressed(self))
+        else:
+            self.call_later(
+                self.app.run_action, self.action, default_namespace=self._parent
+            )
         return self
 
     def _start_active_affect(self) -> None:
@@ -288,7 +306,7 @@ class Button(Widget, can_focus=True):
     @classmethod
     def success(
         cls,
-        label: TextType | None = None,
+        label: ContentText | None = None,
         *,
         name: str | None = None,
         id: str | None = None,
@@ -321,7 +339,7 @@ class Button(Widget, can_focus=True):
     @classmethod
     def warning(
         cls,
-        label: TextType | None = None,
+        label: ContentText | None = None,
         *,
         name: str | None = None,
         id: str | None = None,
@@ -354,7 +372,7 @@ class Button(Widget, can_focus=True):
     @classmethod
     def error(
         cls,
-        label: TextType | None = None,
+        label: ContentText | None = None,
         *,
         name: str | None = None,
         id: str | None = None,
